@@ -15,7 +15,7 @@ assert la_copy.get_location() == la.get_location();
 timezones = ICalGLib.Timezone.get_builtin_timezones();
 timezone = ICalGLib.Timezone.array_element_at(timezones, 0);
 assert timezone.get_display_name() == "Europe/Andorra";
-assert timezones.size() == 415;
+assert timezones.size() > 0;
 
 
 from_tzid = ICalGLib.Timezone.get_builtin_timezone_from_tzid (la.get_tzid());
@@ -42,4 +42,4 @@ assert array.size() == 2;
 timezone1 = ICalGLib.Timezone.array_element_at (array, 0);
 assert timezone1.get_display_name() == la.get_display_name();
 timezone2 = ICalGLib.Timezone.array_element_at (array, 1);
-assert timezone2.get_display_name() == chicago.get_display_name();
\ No newline at end of file
+assert timezone2.get_display_name() == chicago.get_display_name();
